@@ -158,6 +158,7 @@ class Transaction(Resource):
         SettlementConfirmed    = "settlement_confirmed"
         SettlementDeclined     = "settlement_declined"
         SettlementFailed       = "settlement_failed"
+        SettlementPending      = "settlement_pending"
         Settling               = "settling"
         SubmittedForSettlement = "submitted_for_settlement"
         Voided                 = "voided"
@@ -438,11 +439,13 @@ class Transaction(Resource):
                     "store_in_vault_on_success",
                     "store_shipping_address_in_vault",
                     "submit_for_settlement",
-                    "venmo_sdk_session"
+                    "venmo_sdk_session",
+                    "payee_email"
                 ]
             },
             {"custom_fields": ["__any_key__"]},
-            {"descriptor": ["name", "phone", "url"]}
+            {"descriptor": ["name", "phone", "url"]},
+            {"paypal_account": ["payee_email"]}
         ]
 
     def __init__(self, gateway, attributes):
